#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__I__1___TwoPRep_S__0__G__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+690)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+693)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+696)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+699)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]), &(stack[((hsi*3+696)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+711)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*6+699)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+721)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+724)*1+lsi)*1]), &(stack[((hsi*3+721)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+730)*1+lsi)*1]), &(stack[((hsi*6+724)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*3+721)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+693)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+740)*1+lsi)*1]), &(stack[((hsi*3+696)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+746)*1+lsi)*1]), &(stack[((hsi*6+699)*1+lsi)*1]), &(stack[((hsi*6+740)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]), &(stack[((hsi*3+696)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+756)*1+lsi)*1]), &(stack[((hsi*10+711)*1+lsi)*1]), &(stack[((hsi*10+746)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*6+699)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*10+730)*1+lsi)*1]), &(stack[((hsi*10+711)*1+lsi)*1]), &(stack[((hsi*6+724)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*15+756)*1+lsi)*1]), &(stack[((hsi*10+730)*1+lsi)*1]), &(stack[((hsi*10+711)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+690)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+807)*1+lsi)*1]), &(stack[((hsi*6+740)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*3+696)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+817)*1+lsi)*1]), &(stack[((hsi*10+746)*1+lsi)*1]), &(stack[((hsi*10+807)*1+lsi)*1]), &(stack[((hsi*6+699)*1+lsi)*1]), &(stack[((hsi*6+740)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+832)*1+lsi)*1]), &(stack[((hsi*15+756)*1+lsi)*1]), &(stack[((hsi*15+817)*1+lsi)*1]), &(stack[((hsi*10+711)*1+lsi)*1]), &(stack[((hsi*10+746)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+853)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*21+832)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*15+756)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+711)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+696)*1+lsi)*1]), &(stack[((hsi*3+711)*1+lsi)*1]), &(stack[((hsi*3+721)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+881)*1+lsi)*1]), &(stack[((hsi*6+696)*1+lsi)*1]), &(stack[((hsi*6+724)*1+lsi)*1]), &(stack[((hsi*3+711)*1+lsi)*1]), &(stack[((hsi*3+721)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+891)*1+lsi)*1]), &(stack[((hsi*10+881)*1+lsi)*1]), &(stack[((hsi*10+730)*1+lsi)*1]), &(stack[((hsi*6+696)*1+lsi)*1]), &(stack[((hsi*6+724)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+906)*1+lsi)*1]), &(stack[((hsi*15+891)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*10+881)*1+lsi)*1]), &(stack[((hsi*10+730)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+711)*1+lsi)*1]), &(stack[((hsi*21+906)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*15+891)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*84+927)*1+lsi)*1]), &(stack[((hsi*28+711)*1+lsi)*1]), &(stack[((hsi*28+853)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*84+0)*1+lsi)*1]),&(stack[((hsi*84+927)*1+lsi)*1]),84);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+881)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+884)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]), &(stack[((hsi*3+881)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+890)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*6+884)*1+lsi)*1]), &(stack[((hsi*3+693)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*10+807)*1+lsi)*1]), &(stack[((hsi*10+890)*1+lsi)*1]), &(stack[((hsi*6+740)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1011)*1+lsi)*1]), &(stack[((hsi*15+817)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*10+746)*1+lsi)*1]), &(stack[((hsi*10+807)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1032)*1+lsi)*1]), &(stack[((hsi*21+832)*1+lsi)*1]), &(stack[((hsi*21+1011)*1+lsi)*1]), &(stack[((hsi*15+756)*1+lsi)*1]), &(stack[((hsi*15+817)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1060)*1+lsi)*1]), &(stack[((hsi*28+853)*1+lsi)*1]), &(stack[((hsi*28+1032)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*21+832)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1096)*1+lsi)*1]), &(stack[((hsi*28+711)*1+lsi)*1]), &(stack[((hsi*28+853)*1+lsi)*1]), &(stack[((hsi*21+906)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1132)*1+lsi)*1]), &(stack[((hsi*36+1096)*1+lsi)*1]), &(stack[((hsi*36+1060)*1+lsi)*1]), &(stack[((hsi*28+853)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+84)*1+lsi)*1]),&(stack[((hsi*108+1132)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+739)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+742)*1+lsi)*1]), &(stack[((hsi*3+881)*1+lsi)*1]), &(stack[((hsi*3+739)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+900)*1+lsi)*1]), &(stack[((hsi*6+884)*1+lsi)*1]), &(stack[((hsi*6+742)*1+lsi)*1]), &(stack[((hsi*3+690)*1+lsi)*1]), &(stack[((hsi*3+881)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+690)*1+lsi)*1]), &(stack[((hsi*10+890)*1+lsi)*1]), &(stack[((hsi*10+900)*1+lsi)*1]), &(stack[((hsi*6+705)*1+lsi)*1]), &(stack[((hsi*6+884)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*15+690)*1+lsi)*1]), &(stack[((hsi*10+807)*1+lsi)*1]), &(stack[((hsi*10+890)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1240)*1+lsi)*1]), &(stack[((hsi*21+1011)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*15+817)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1268)*1+lsi)*1]), &(stack[((hsi*28+1032)*1+lsi)*1]), &(stack[((hsi*28+1240)*1+lsi)*1]), &(stack[((hsi*21+832)*1+lsi)*1]), &(stack[((hsi*21+1011)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+807)*1+lsi)*1]), &(stack[((hsi*36+1060)*1+lsi)*1]), &(stack[((hsi*36+1268)*1+lsi)*1]), &(stack[((hsi*28+853)*1+lsi)*1]), &(stack[((hsi*28+1032)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1304)*1+lsi)*1]), &(stack[((hsi*36+1096)*1+lsi)*1]), &(stack[((hsi*36+1060)*1+lsi)*1]), &(stack[((hsi*28+711)*1+lsi)*1]), &(stack[((hsi*28+853)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1349)*1+lsi)*1]), &(stack[((hsi*45+1304)*1+lsi)*1]), &(stack[((hsi*45+807)*1+lsi)*1]), &(stack[((hsi*36+1060)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+192)*1+lsi)*1]),&(stack[((hsi*135+1349)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+705)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+708)*1+lsi)*1]), &(stack[((hsi*3+739)*1+lsi)*1]), &(stack[((hsi*3+705)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+852)*1+lsi)*1]), &(stack[((hsi*6+742)*1+lsi)*1]), &(stack[((hsi*6+708)*1+lsi)*1]), &(stack[((hsi*3+881)*1+lsi)*1]), &(stack[((hsi*3+739)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+714)*1+lsi)*1]), &(stack[((hsi*10+900)*1+lsi)*1]), &(stack[((hsi*10+852)*1+lsi)*1]), &(stack[((hsi*6+884)*1+lsi)*1]), &(stack[((hsi*6+742)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+862)*1+lsi)*1]), &(stack[((hsi*15+690)*1+lsi)*1]), &(stack[((hsi*15+714)*1+lsi)*1]), &(stack[((hsi*10+890)*1+lsi)*1]), &(stack[((hsi*10+900)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1484)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*21+862)*1+lsi)*1]), &(stack[((hsi*15+771)*1+lsi)*1]), &(stack[((hsi*15+690)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+748)*1+lsi)*1]), &(stack[((hsi*28+1240)*1+lsi)*1]), &(stack[((hsi*28+1484)*1+lsi)*1]), &(stack[((hsi*21+1011)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1512)*1+lsi)*1]), &(stack[((hsi*36+1268)*1+lsi)*1]), &(stack[((hsi*36+748)*1+lsi)*1]), &(stack[((hsi*28+1032)*1+lsi)*1]), &(stack[((hsi*28+1240)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1557)*1+lsi)*1]), &(stack[((hsi*45+807)*1+lsi)*1]), &(stack[((hsi*45+1512)*1+lsi)*1]), &(stack[((hsi*36+1060)*1+lsi)*1]), &(stack[((hsi*36+1268)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1612)*1+lsi)*1]), &(stack[((hsi*45+1304)*1+lsi)*1]), &(stack[((hsi*45+807)*1+lsi)*1]), &(stack[((hsi*36+1096)*1+lsi)*1]), &(stack[((hsi*36+1060)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1667)*1+lsi)*1]), &(stack[((hsi*55+1612)*1+lsi)*1]), &(stack[((hsi*55+1557)*1+lsi)*1]), &(stack[((hsi*45+807)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+327)*1+lsi)*1]),&(stack[((hsi*165+1667)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1011)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1014)*1+lsi)*1]), &(stack[((hsi*3+705)*1+lsi)*1]), &(stack[((hsi*3+1011)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+729)*1+lsi)*1]), &(stack[((hsi*6+708)*1+lsi)*1]), &(stack[((hsi*6+1014)*1+lsi)*1]), &(stack[((hsi*3+739)*1+lsi)*1]), &(stack[((hsi*3+705)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1011)*1+lsi)*1]), &(stack[((hsi*10+852)*1+lsi)*1]), &(stack[((hsi*10+729)*1+lsi)*1]), &(stack[((hsi*6+742)*1+lsi)*1]), &(stack[((hsi*6+708)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1026)*1+lsi)*1]), &(stack[((hsi*15+714)*1+lsi)*1]), &(stack[((hsi*15+1011)*1+lsi)*1]), &(stack[((hsi*10+900)*1+lsi)*1]), &(stack[((hsi*10+852)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1047)*1+lsi)*1]), &(stack[((hsi*21+862)*1+lsi)*1]), &(stack[((hsi*21+1026)*1+lsi)*1]), &(stack[((hsi*15+690)*1+lsi)*1]), &(stack[((hsi*15+714)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1011)*1+lsi)*1]), &(stack[((hsi*28+1484)*1+lsi)*1]), &(stack[((hsi*28+1047)*1+lsi)*1]), &(stack[((hsi*21+786)*1+lsi)*1]), &(stack[((hsi*21+862)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1047)*1+lsi)*1]), &(stack[((hsi*36+748)*1+lsi)*1]), &(stack[((hsi*36+1011)*1+lsi)*1]), &(stack[((hsi*28+1240)*1+lsi)*1]), &(stack[((hsi*28+1484)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+852)*1+lsi)*1]), &(stack[((hsi*45+1512)*1+lsi)*1]), &(stack[((hsi*45+1047)*1+lsi)*1]), &(stack[((hsi*36+1268)*1+lsi)*1]), &(stack[((hsi*36+748)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1011)*1+lsi)*1]), &(stack[((hsi*55+1557)*1+lsi)*1]), &(stack[((hsi*55+852)*1+lsi)*1]), &(stack[((hsi*45+807)*1+lsi)*1]), &(stack[((hsi*45+1512)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+690)*1+lsi)*1]), &(stack[((hsi*55+1612)*1+lsi)*1]), &(stack[((hsi*55+1557)*1+lsi)*1]), &(stack[((hsi*45+1304)*1+lsi)*1]), &(stack[((hsi*45+807)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+1832)*1+lsi)*1]), &(stack[((hsi*66+690)*1+lsi)*1]), &(stack[((hsi*66+1011)*1+lsi)*1]), &(stack[((hsi*55+1557)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+492)*1+lsi)*1]),&(stack[((hsi*198+1832)*1+lsi)*1]),198);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 690 */
}

#ifdef __cplusplus
};
#endif
